import { ApolloQueryResult } from 'apollo-client';
import { ExecutionResult } from 'graphql';
import { FetchResult } from '@apollo/client';
import { CustomQuery } from '@vue-storefront/core';
import { AddConfigurableProductsToCartInput, AddConfigurableProductsToCartMutation, AddSimpleProductsToCartInput, AddSimpleProductsToCartMutation, AppliedCoupon, ApplyCouponToCartInput, ApplyCouponToCartMutation, AvailableShippingMethod, BundleProduct, Cart as CartInterface, CartItemInterface, CartQuery, CategoryFilterInput, CategoryListQuery, CategoryListQueryVariables, CategorySearchQuery, CategorySearchQueryVariables, CategoryTree, CmsPage, CmsPageQuery, ConfigurableProduct, ConfigurableProductDetailQuery, CreateCustomerAddressMutation, CreateEmptyCartMutation, CustomerAddress as CustomerAddressInterface, CustomerAddressInput, CustomerAvailablePaymentMethodsQuery, CustomerCartQuery, CustomerCreateInput, CustomerDataFragment as CustomerFragment, CustomerOrder as CustomerOrderInterface, CustomerOrdersQuery, CustomerOrdersQueryVariables, CustomerQuery, CustomerUpdateInput, DeleteCustomerAddressMutation, GenerateCustomerTokenMutation, GetMenuCategoryQuery, GuestAvailablePaymentMethodsQuery, MergeCartsMutation, Order as OrderInterface, PlaceOrderInput, PlaceOrderMutation, ProductAttributeFilterInput, ProductAttributeSortInput, ProductDetailsQuery, ProductInterface, ProductReviewQuery, ProductsListQuery, RelatedProductQuery, RemoveCouponFromCartInput, RemoveCouponFromCartMutation, RemoveItemFromCartInput, RemoveItemFromCartMutation, RevokeCustomerTokenMutation, SetBillingAddressOnCartInput, SetBillingAddressOnCartMutation, SetGuestEmailOnCartInput, SetGuestEmailOnCartMutation, SetPaymentMethodOnCartInput, SetPaymentMethodOnCartMutation, SetShippingAddressesOnCartInput, SetShippingAddressesOnCartMutation, SetShippingMethodsOnCartInput, SetShippingMethodsOnCartMutation, ShippingCartAddress, StoreConfigQuery, UpdateCartItemsInput, UpdateCartItemsMutation, UpdateCustomerAddressMutation, UpsellProductsQuery, UrlResloverQuery, Wishlist as WishlistInterface, WishlistItemInterface, WishlistQuery, WishlistQueryVariables } from './GraphQL';
export interface Product extends ProductInterface, ConfigurableProduct, BundleProduct {
}
export declare type AddressOnCart = ShippingCartAddress;
export declare type Cart = CartInterface;
export declare type CartItem = CartItemInterface;
export declare type Category = CategoryTree;
export declare type CategoryFilter = CategoryFilterInput;
export declare type CategoryMenu = CategoryTree;
export declare type Coupon = AppliedCoupon;
export declare type Customer = CustomerFragment;
export declare type CustomerAddress = CustomerAddressInterface;
export declare type CustomerOrder = CustomerOrderInterface;
export declare type CustomerUpdateParameters = CustomerCreateInput;
export declare type Order = OrderInterface;
export declare type Page = CmsPage;
export declare type ProductAttributeFilter = ProductAttributeFilterInput;
export declare type ProductReviews = ProductReviewQuery['products']['items'][0];
export declare type ProductReview = ProductReviewQuery['products']['items'][0]['reviews']['items'][0];
export declare type Route = UrlResloverQuery['urlResolver'];
export declare type ShippingMethod = AvailableShippingMethod;
export declare type StoreConfig = StoreConfigQuery['storeConfig'];
export declare type Wishlist = WishlistInterface;
export declare type WishlistProduct = WishlistItemInterface;
export declare const enum ProductsQueryType {
    List = "LIST",
    Detail = "DETAIL"
}
export declare type GetProductSearchParams = {
    pageSize?: number;
    currentPage?: number;
    search?: string;
    filter?: ProductAttributeFilterInput;
    sort?: ProductAttributeSortInput;
};
export declare enum MagentoCustomerGender {
    Male = 1,
    Female = 2
}
export interface MagentoApiMethods {
    addConfigurableProductsToCart(input: AddConfigurableProductsToCartInput): Promise<FetchResult<AddConfigurableProductsToCartMutation>>;
    addSimpleProductsToCart(input: AddSimpleProductsToCartInput): Promise<FetchResult<AddSimpleProductsToCartMutation>>;
    applyCouponToCart(input: ApplyCouponToCartInput): Promise<FetchResult<ApplyCouponToCartMutation>>;
    cart(cartId: string): Promise<ApolloQueryResult<CartQuery>>;
    categoryList(categoryFilter?: CategoryListQueryVariables): Promise<ApolloQueryResult<CategoryListQuery>>;
    categorySearch(categoryFilter?: CategorySearchQueryVariables): Promise<ApolloQueryResult<CategorySearchQuery>>;
    changeCustomerPassword(currentPassword: string, newPassword: string): Promise<CustomerFragment>;
    cmsPage(indentifier: string): Promise<ApolloQueryResult<CmsPageQuery>>;
    createCustomer(input: CustomerCreateInput): Promise<CustomerFragment>;
    createCustomerAddress(input: CustomerAddressInput): Promise<FetchResult<CreateCustomerAddressMutation>>;
    createEmptyCart(): Promise<FetchResult<CreateEmptyCartMutation>>;
    customer(): Promise<ApolloQueryResult<CustomerQuery>>;
    customerCart(): Promise<ApolloQueryResult<CustomerCartQuery>>;
    customerOrders(orderParams: CustomerOrdersQueryVariables): Promise<ApolloQueryResult<CustomerOrdersQuery>>;
    deleteCustomerAddress(addressId: number): Promise<ExecutionResult<DeleteCustomerAddressMutation>>;
    generateCustomerToken(email: string, password: string): Promise<FetchResult<GenerateCustomerTokenMutation>>;
    getMenuCategory(params: CategoryFilterInput, customQuery?: CustomQuery): Promise<GetMenuCategoryQuery>;
    getAvailablePaymentMethods(params: {
        cartId: string;
    }, customQuery?: CustomQuery): Promise<ApolloQueryResult<GuestAvailablePaymentMethodsQuery | CustomerAvailablePaymentMethodsQuery>>;
    mergeCarts(sourceCartId: string, destinationCartId: string): Promise<FetchResult<MergeCartsMutation>>;
    placeOrder(input: PlaceOrderInput): Promise<FetchResult<PlaceOrderMutation>>;
    productDetail(searchParams: GetProductSearchParams, customQuery?: CustomQuery): Promise<ApolloQueryResult<ProductDetailsQuery>>;
    configurableProductDetail(searchParams: GetProductSearchParams, customQuery?: CustomQuery): Promise<ApolloQueryResult<ConfigurableProductDetailQuery>>;
    relatedProduct(searchParams: GetProductSearchParams, customQuery?: CustomQuery): Promise<ApolloQueryResult<RelatedProductQuery>>;
    upsellProduct(searchParams: GetProductSearchParams, customQuery?: CustomQuery): Promise<ApolloQueryResult<UpsellProductsQuery>>;
    productReview(searchParams: GetProductSearchParams, customQuery?: CustomQuery): Promise<ApolloQueryResult<ProductReviewQuery>>;
    products(searchParams: GetProductSearchParams, customQuery?: CustomQuery): Promise<ApolloQueryResult<ProductsListQuery>>;
    removeCouponFromCart(input: RemoveCouponFromCartInput): Promise<FetchResult<RemoveCouponFromCartMutation>>;
    removeItemFromCart(input: RemoveItemFromCartInput): Promise<FetchResult<RemoveItemFromCartMutation>>;
    revokeCustomerToken(): Promise<FetchResult<RevokeCustomerTokenMutation>>;
    setBillingAddressOnCart(input: SetBillingAddressOnCartInput): Promise<FetchResult<SetBillingAddressOnCartMutation>>;
    setGuestEmailOnCart(input: SetGuestEmailOnCartInput): Promise<FetchResult<SetGuestEmailOnCartMutation>>;
    setPaymentMethodOnCart(input: SetPaymentMethodOnCartInput): Promise<FetchResult<SetPaymentMethodOnCartMutation>>;
    setPaymentMethodOnCart(input: SetShippingAddressesOnCartInput): Promise<FetchResult<SetShippingAddressesOnCartMutation>>;
    setShippingMethodsOnCart(input: SetShippingMethodsOnCartInput): Promise<FetchResult<SetShippingMethodsOnCartMutation>>;
    setShippingAddressesOnCart(input: SetShippingAddressesOnCartInput): Promise<FetchResult<SetShippingAddressesOnCartMutation>>;
    storeConfig(): Promise<ApolloQueryResult<StoreConfigQuery>>;
    updateCartItems(input: UpdateCartItemsInput): Promise<FetchResult<UpdateCartItemsMutation>>;
    updateCustomer(input: CustomerUpdateInput): Promise<CustomerFragment>;
    updateCustomerAddress(input: {
        addressId: number;
        input: CustomerAddressInput;
    }): Promise<FetchResult<UpdateCustomerAddressMutation>>;
    urlResolver(url: string): Promise<ApolloQueryResult<UrlResloverQuery>>;
    wishlist(queryParams: WishlistQueryVariables): Promise<ApolloQueryResult<WishlistQuery>>;
}
